@@ -17,7 +17,7 @@ from pmb.config.sudo import which_sudo
 #
 # Exported variables (internal configuration)
 #
-version = "1.43.1"
+version = "1.45.0"
 pmb_src = os.path.normpath(os.path.realpath(__file__) + "/../../..")
 apk_keys_path = pmb_src + "/pmb/data/keys"
 arch_native = pmb.parse.arch.alpine_native()
@@ -27,7 +27,8 @@ arch_native = pmb.parse.arch.alpine_native()
 # Update this frequently to prevent a MITM attack with an outdated version
 # (which may contain a vulnerable apk/openssl, and allows an attacker to
 # exploit the system!)
-apk_tools_min_version = {"edge": "2.12.9-r3",
+apk_tools_min_version = {"edge": "2.12.9-r5",
+                         "v3.16": "2.12.9-r3",
                          "v3.15": "2.12.7-r3",
                          "v3.14": "2.12.7-r0",
                          "v3.13": "2.12.7-r0",
@@ -338,7 +339,7 @@ necessary_kconfig_options_anbox = {
             "TMPFS_XATTR": True,
             "ANDROID_BINDER_IPC": True,
             "ANDROID_BINDERFS": False,
-            "ANDROID_BINDER_DEVICES": ["binder", "hwbinder"],
+            "ANDROID_BINDER_DEVICES": ["binder", "hwbinder", "vndbinder"],
             "NETFILTER_XTABLES": True,
             "NETFILTER_XT_MATCH_COMMENT": True,
             "IP_NF_MANGLE": True,
